package semantics;

use strict;

sub getArgCategories
{
    my $arg_categories;

    open(SEM,"data/semantic-category.file");
    while (my $line=<SEM>)
    {
	chop $line;
	my ($predicate, $argument, @categories) = split(/ /,$line);
	@{ $arg_categories->{$predicate}->{$argument} } = @categories;
    }
    close(SEM);

    
    return  $arg_categories;
}


sub correctCategory
{
    my $categories = $_[0];
    my $candidate_lemma = $_[1];
    my $candidate_pos = $_[2];
    my $candidate_ne = $_[3];
    my $candidate_ss = $_[4];

    my $correct_category = 0;

    foreach my $category (@{ $categories })
    {
	if ($category eq "COGNITIVE")
	{
	    if ($candidate_pos=~/NNP/)
	    {
		if ($candidate_ne=~/ORG_DESC/ || $candidate_ne=~/ORGANIZATION/ || $candidate_ne=~/PER_DESC/ ||$candidate_ne=~/PERSON/ || $candidate_ne=~/ANIMA/ || $candidate_ne=~/NORP/)
		{
		    $correct_category = 1;
		}
	    }
	    elsif ($candidate_pos=~/PRP/)
	    {
		if ($candidate_lemma eq "i" || $candidate_lemma eq "we" || $candidate_lemma eq "you" || $candidate_lemma eq "he" || $candidate_lemma eq "she")
		{
		    $correct_category = 1;
		}
	    }
	    else
	    {
		if ($candidate_ss=~/group/ || $candidate_ss=~/person/ || $candidate_ss=~/animal/)
		{
		    $correct_category = 1;
		}	    
	    }
	}
	elsif ($category eq "TANGIBLE")
	{
	    if ($candidate_pos=~/NNP/)
	    {
		if ($candidate_ne=~/PLANT/ || $candidate_ne=~/PRODUCT/ || $candidate_ne=~/PRODUCT_DESC/ || $candidate_ne=~/SUBSTANCE/ || $candidate_ne=~/WORK_OF_ART/)
		{
		    $correct_category = 1;
		}
	    }
	    else
	    {
		if ($candidate_ss=~/possession/ || $candidate_ss=~/artifact/ || $candidate_ss=~/substance/ || $candidate_ss=~/body/ || $candidate_ss=~/food/ || $candidate_ss=~/object/ || $candidate_ss=~/plant/)
		{
		    $correct_category = 1;
		}
	    }
	}
	elsif ($category eq "EVENTIVE")
	{
	    if ($candidate_pos=~/NNP/)
	    {
		if ($candidate_ne=~/DISEASE/ || $candidate_ne=~/EVENT/ || $candidate_ne=~/GAME/ || $candidate_ne=~/LAW/)
		{
		    $correct_category = 1;
		}
	    }
	    else
	    {
		if ($candidate_ss=~/cognition/ || $candidate_ss=~/communication/ || $candidate_ss=~/phenomenon/ || $candidate_ss=~/process/ || $candidate_ss=~/feeling/ || $candidate_ss=~/event/ || $candidate_ss=~/act/)
		{
		    $correct_category = 1;
		}	    
	    }
	}
	elsif ($category eq "RELATIVE")
	{
	    if ($candidate_ss=~/state/ || $candidate_ss=~/relation/ || $candidate_ss=~/shape/ || $candidate_ss=~/attribute/ || $candidate_ss=~/motive/)
	    {
		$correct_category = 1;
	    }	    
	}
	elsif ($category eq "LOCATIVE")
	{
	    if ($candidate_ne=~/CONTACT_INFO/ || $candidate_ne=~/FAC/ || $candidate_ne=~/FAC_DESC/ || $candidate_ne=~/LOCATION/)
	    {
		$correct_category = 1;
	    }
	    elsif ($candidate_ss=~/location/)
	    {
		$correct_category = 1;
	    }	    
	}
	elsif ($category eq "TIME-TIVE")
	{
	    if ($candidate_ne=~/DATE/ || $candidate_ne=~/TIME/)
	    {
		$correct_category = 1;
	    }
	    elsif ($candidate_ss=~/time/)
	    {
		$correct_category = 1;
	    }	    
	}
	elsif ($category eq "MESURABLE")
	{
	    if ($candidate_ne=~/MONEY/ || $candidate_ne=~/ORDINAL/ || $candidate_ne=~/PERCENT/ || $candidate_ne=~/QUANTITY/ || $candidate_ne=~/CARDINAL/)
	    {
		$correct_category = 1;
	    }
	    elsif ($candidate_ss=~/quantity/)
	    {
		$correct_category = 1;
	    }
	}
    }

    return $correct_category;
}



1;
